/**
 * @file
 * Dynamically shows a date/time as a cacheable "time ago" string.
 */

(function ($, Drupal, drupalSettings) {

  /**
   * Shows a date/time as a cacheable "time ago" string.
   *
   * We use the timeago jquery plugin (http://timeago.yarp.com) to replace the
   * formatted date with a "time ago" string. We don't return a "time ago" from
   * server because that value is changing very often (every second), meaning
   * that we cannot cache the value and, as an effect, the whole page will
   * become uncacheable. Instead we display the formatted date/time and then, in
   * javascript enabled browsers, we replace the formatted date/time with a
   * "time ago" expression that is generated by plugin. The value rendered by
   * the plugin is refreshed each minute.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Uses timeago jquery plugin for 'joinup_timestamp_timeago' formatter.
   *
   * @see http://timeago.yarp.com
   */
  Drupal.behaviors.timestampTimeago = {
    attach: function (context) {
      // Merge the custom settings.
      $.extend(true, $.timeago.settings,
        drupalSettings.joinupCore.timeagoSettings
      );
      $('time.js-joinup-timestamp-timeago').timeago();
    }
  };

})(jQuery, Drupal, drupalSettings);
